@@ -1,18 +1,21 @@
-#include <config.h>
-#include <rsspp_internal.h>
-#include <utils.h>
+#include "rsspp_internal.h"
+
 #include <cstring>
 
+#include "config.h"
+#include "utils.h"
+
 using namespace newsboat;
 
 namespace rsspp {
 
-void rss_20_parser::parse_feed(feed& f, xmlNode * rootNode) {
+void rss_20_parser::parse_feed(feed& f, xmlNode* rootNode)
+{
 	if (!rootNode)
 		throw exception(_("XML root node is NULL"));
 
 	if (rootNode->ns) {
-		const char * ns = (const char *)rootNode->ns->href;
+		const char* ns = (const char*)rootNode->ns->href;
 		if (strcmp(ns, RSS20USERLAND_URI) == 0) {
 			this->ns = strdup(ns);
 		}
@@ -21,25 +24,28 @@ void rss_20_parser::parse_feed(feed& f, xmlNode * rootNode) {
 	rss_09x_parser::parse_feed(f, rootNode);
 }
 
-void rss_09x_parser::parse_feed(feed& f, xmlNode * rootNode) {
+void rss_09x_parser::parse_feed(feed& f, xmlNode* rootNode)
+{
 	if (!rootNode)
 		throw exception(_("XML root node is NULL"));
 
 	globalbase = get_prop(rootNode, "base", XML_URI);
 
-	xmlNode * channel = rootNode->children;
-	while (channel && strcmp((const char *)channel->name, "channel")!=0)
+	xmlNode* channel = rootNode->children;
+	while (channel && strcmp((const char*)channel->name, "channel") != 0)
 		channel = channel->next;
 
 	if (!channel)
 		throw exception(_("no RSS channel found"));
 
-	for (xmlNode * node = channel->children; node != nullptr; node = node->next) {
+	for (xmlNode* node = channel->children; node != nullptr;
+		node = node->next) {
 		if (node_is(node, "title", ns)) {
 			f.title = get_content(node);
 			f.title_type = "text";
 		} else if (node_is(node, "link", ns)) {
-			f.link = utils::absolute_url(globalbase, get_content(node));
+			f.link = utils::absolute_url(
+				globalbase, get_content(node));
 		} else if (node_is(node, "description", ns)) {
 			f.description = get_content(node);
 		} else if (node_is(node, "language", ns)) {
@@ -52,7 +58,8 @@ void rss_09x_parser::parse_feed(feed& f, xmlNode * rootNode) {
 	}
 }
 
-item rss_09x_parser::parse_item(xmlNode * itemNode) {
+item rss_09x_parser::parse_item(xmlNode* itemNode)
+{
 	item it;
 	std::string author;
 	std::string dc_date;
@@ -61,7 +68,8 @@ item rss_09x_parser::parse_item(xmlNode * itemNode) {
 	if (base.empty())
 		base = globalbase;
 
-	for (xmlNode * node = itemNode->children; node != nullptr; node = node->next) {
+	for (xmlNode* node = itemNode->children; node != nullptr;
+		node = node->next) {
 		if (node_is(node, "title", ns)) {
 			it.title = get_content(node);
 			it.title_type = "text";
@@ -90,12 +98,17 @@ item rss_09x_parser::parse_item(xmlNode * itemNode) {
 			dc_date = w3cdtf_to_rfc822(get_content(node));
 		} else if (node_is(node, "author", ns)) {
 			std::string authorfield = get_content(node);
-			if (authorfield[authorfield.length()-1] == ')') {
-				it.author_email = utils::tokenize(authorfield, " ")[0];
+			if (authorfield[authorfield.length() - 1] == ')') {
+				it.author_email =
+					utils::tokenize(authorfield, " ")[0];
 				unsigned int start, end;
-				end = authorfield.length()-2;
-				for (start = end; start > 0 && authorfield[start] != '('; start--) { }
-				it.author = authorfield.substr(start+1, end-start);
+				end = authorfield.length() - 2;
+				for (start = end;
+					start > 0 && authorfield[start] != '(';
+					start--) {
+				}
+				it.author = authorfield.substr(
+					start + 1, end - start);
 			} else {
 				it.author_email = authorfield;
 				it.author = authorfield;
@@ -115,12 +128,17 @@ item rss_09x_parser::parse_item(xmlNode * itemNode) {
 				it.enclosure_type = std::move(type);
 			}
 		} else if (node_is(node, "group", MEDIA_RSS_URI)) {
-			for (xmlNode * mnode = node->children; mnode != nullptr; mnode = mnode->next) {
+			for (xmlNode* mnode = node->children; mnode != nullptr;
+				mnode = mnode->next) {
 				if (node_is(mnode, "content", MEDIA_RSS_URI)) {
-					const std::string type = get_prop(mnode, "type");
-					if (utils::is_valid_podcast_type(type)) {
-						it.enclosure_url = get_prop(mnode, "url");
-						it.enclosure_type = std::move(type);
+					const std::string type =
+						get_prop(mnode, "type");
+					if (utils::is_valid_podcast_type(
+						    type)) {
+						it.enclosure_url =
+							get_prop(mnode, "url");
+						it.enclosure_type =
+							std::move(type);
 					}
 				}
 			}
@@ -138,8 +156,9 @@ item rss_09x_parser::parse_item(xmlNode * itemNode) {
 	return it;
 }
 
-rss_09x_parser::~rss_09x_parser() {
-	free((void *)ns);
+rss_09x_parser::~rss_09x_parser()
+{
+	free((void*)ns);
 }
 
-}
+} // namespace rsspp
