@@ -1,13 +1,18 @@
+#include "history.h"
+
 #include <fstream>
-#include <history.h>
 
 namespace newsboat {
 
-history::history() : idx(0) { }
+history::history()
+	: idx(0)
+{
+}
 
-history::~history() { }
+history::~history() {}
 
-void history::add_line(const std::string& line) {
+void history::add_line(const std::string& line)
+{
 	/*
 	 * When a line is added, we need to do so and
 	 * reset the index so that the next prev/next
@@ -19,24 +24,27 @@ void history::add_line(const std::string& line) {
 	idx = 0;
 }
 
-std::string history::prev() {
+std::string history::prev()
+{
 	if (idx < lines.size()) {
 		return lines[idx++];
 	}
 	if (lines.size() == 0) {
 		return "";
 	}
-	return lines[idx-1];
+	return lines[idx - 1];
 }
 
-std::string history::next() {
+std::string history::next()
+{
 	if (idx > 0) {
 		return lines[--idx];
 	}
 	return "";
 }
 
-void history::load_from_file(const std::string& file) {
+void history::load_from_file(const std::string& file)
+{
 	std::fstream f;
 	f.open(file.c_str(), std::fstream::in);
 	if (f.is_open()) {
@@ -50,14 +58,15 @@ void history::load_from_file(const std::string& file) {
 	}
 }
 
-void history::save_to_file(const std::string& file, unsigned int limit) {
+void history::save_to_file(const std::string& file, unsigned int limit)
+{
 	std::fstream f;
 	f.open(file.c_str(), std::fstream::out | std::fstream::trunc);
 	if (f.is_open()) {
 		if (limit > lines.size())
 			limit = lines.size();
 		if (limit > 0) {
-			for (unsigned int i=limit-1; i>0; i--) {
+			for (unsigned int i = limit - 1; i > 0; i--) {
 				f << lines[i] << std::endl;
 			}
 			f << lines[0] << std::endl;
@@ -65,5 +74,4 @@ void history::save_to_file(const std::string& file, unsigned int limit) {
 	}
 }
 
-
-}
+} // namespace newsboat
