@@ -1,20 +1,22 @@
+#include "remote_api.h"
+
 #include <fstream>
+#include <glob.h>
 #include <iostream>
 #include <unistd.h>
-#include <glob.h>
 
-#include <remote_api.h>
-#include <utils.h>
+#include "utils.h"
 
 namespace newsboat {
 
-const std::string remote_api::read_password(const std::string& file) {
+const std::string remote_api::read_password(const std::string& file)
+{
 	glob_t exp;
 	std::ifstream ifs;
 	std::string pass = "";
 
 	int res = glob(file.c_str(), GLOB_ERR, nullptr, &exp);
-	if (! res && exp.gl_pathc == 1 && exp.gl_pathv) {
+	if (!res && exp.gl_pathc == 1 && exp.gl_pathv) {
 		ifs.open(exp.gl_pathv[0]);
 	}
 	globfree(&exp);
@@ -25,7 +27,8 @@ const std::string remote_api::read_password(const std::string& file) {
 	return pass;
 }
 
-const std::string remote_api::eval_password(const std::string& cmd) {
+const std::string remote_api::eval_password(const std::string& cmd)
+{
 	std::string pass = utils::get_command_output(cmd);
 	std::string::size_type pos = pass.find_first_of("\n\r");
 
@@ -36,11 +39,13 @@ const std::string remote_api::eval_password(const std::string& cmd) {
 	return pass;
 }
 
-credentials remote_api::get_credentials(const std::string& scope, const std::string& name) {
-	std::string user = cfg->get_configvalue(scope+"-login");
-	std::string pass = cfg->get_configvalue(scope+"-password");
-	std::string pass_file = cfg->get_configvalue(scope+"-passwordfile");
-	std::string pass_eval = cfg->get_configvalue(scope+"-passwordeval");
+credentials remote_api::get_credentials(const std::string& scope,
+	const std::string& name)
+{
+	std::string user = cfg->get_configvalue(scope + "-login");
+	std::string pass = cfg->get_configvalue(scope + "-password");
+	std::string pass_file = cfg->get_configvalue(scope + "-passwordfile");
+	std::string pass_eval = cfg->get_configvalue(scope + "-passwordeval");
 
 	bool flushed = false;
 
@@ -51,7 +56,7 @@ credentials remote_api::get_credentials(const std::string& scope, const std::str
 		printf("Username for %s: ", name.c_str());
 		std::cin >> user;
 		if (user.empty()) {
-			return { "", "" };
+			return {"", ""};
 		}
 	}
 
@@ -66,16 +71,16 @@ credentials remote_api::get_credentials(const std::string& scope, const std::str
 				std::cout.flush();
 			}
 			// Find a way to do this in C++ by removing cin echoing.
-			std::string pass_prompt = "Password for "+name+": ";
+			std::string pass_prompt = "Password for " + name + ": ";
 			pass = std::string(getpass(pass_prompt.c_str()));
 		}
 
 		if (pass.empty()) {
-			return { "", "" };
+			return {"", ""};
 		}
 	}
 
-	return { user, pass };
+	return {user, pass};
 }
 
-}
+} // namespace newsboat
