@@ -1,17 +1,24 @@
-#include <ttrss_api.h>
-#include <logger.h>
+#include "ttrss_api.h"
+
+#include "logger.h"
 
 namespace newsboat {
 
-ttrss_urlreader::ttrss_urlreader(const std::string& url_file, remote_api * a) : file(url_file), api(a) { }
+ttrss_urlreader::ttrss_urlreader(const std::string& url_file, remote_api* a)
+	: file(url_file)
+	, api(a)
+{
+}
 
-ttrss_urlreader::~ttrss_urlreader() { }
+ttrss_urlreader::~ttrss_urlreader() {}
 
-void ttrss_urlreader::write_config() {
+void ttrss_urlreader::write_config()
+{
 	// NOTHING
 }
 
-void ttrss_urlreader::reload() {
+void ttrss_urlreader::reload()
+{
 	urls.clear();
 	tags.clear();
 	alltags.clear();
@@ -19,14 +26,14 @@ void ttrss_urlreader::reload() {
 	file_urlreader ur(file);
 	ur.reload();
 
-	//std::vector<std::string>& file_urls(ur.get_urls());
+	// std::vector<std::string>& file_urls(ur.get_urls());
 	auto& file_urls(ur.get_urls());
-	for (auto url : file_urls) {
-		if (url.substr(0,6) == "query:") {
+	for (const auto& url : file_urls) {
+		if (url.substr(0, 6) == "query:") {
 			urls.push_back(url);
 			std::vector<std::string>& file_tags(ur.get_tags(url));
 			tags[url] = ur.get_tags(url);
-			for (auto tag : file_tags) {
+			for (const auto& tag : file_tags) {
 				alltags.insert(tag);
 			}
 		}
@@ -34,20 +41,21 @@ void ttrss_urlreader::reload() {
 
 	auto feedurls = api->get_subscribed_urls();
 
-	for (auto url : feedurls) {
+	for (const auto& url : feedurls) {
 		LOG(level::DEBUG, "added %s to URL list", url.first);
 		urls.push_back(url.first);
 		tags[url.first] = url.second;
-		for (auto tag : url.second) {
+		for (const auto& tag : url.second) {
 			LOG(level::DEBUG, "%s: added tag %s", url.first, tag);
 			alltags.insert(tag);
 		}
 	}
 }
 
-std::string ttrss_urlreader::get_source() {
+std::string ttrss_urlreader::get_source()
+{
 	return "Tiny Tiny RSS";
 }
 // TODO
 
-}
+} // namespace newsboat
