@@ -1,41 +1,46 @@
-#include "3rd-party/catch.hpp"
+#include "regexmanager.h"
 
-#include <regexmanager.h>
-#include <exceptions.h>
+#include "3rd-party/catch.hpp"
+#include "exceptions.h"
 
 using namespace newsboat;
 
 TEST_CASE("RegexManager throws on invalid `highlight' definition",
-          "[regexmanager]")
+	"[regexmanager]")
 {
 	regexmanager rxman;
 	std::vector<std::string> params;
 
-	SECTION("on `highlight' without parameters") {
+	SECTION("on `highlight' without parameters")
+	{
 		REQUIRE_THROWS_AS(rxman.handle_action("highlight", params),
-				confighandlerexception);
+			confighandlerexception);
 	}
 
-	SECTION("on invalid location") {
+	SECTION("on invalid location")
+	{
 		params = {"invalidloc", "foo", "blue", "red"};
 		REQUIRE_THROWS_AS(rxman.handle_action("highlight", params),
-				confighandlerexception);
+			confighandlerexception);
 	}
 
-	SECTION("on invalid regex") {
+	SECTION("on invalid regex")
+	{
 		params = {"feedlist", "*", "blue", "red"};
 		REQUIRE_THROWS_AS(rxman.handle_action("highlight", params),
-				confighandlerexception);
+			confighandlerexception);
 	}
 
-	SECTION("on invalid command") {
-		REQUIRE_THROWS_AS(rxman.handle_action("an-invalid-command", params),
-				confighandlerexception);
+	SECTION("on invalid command")
+	{
+		REQUIRE_THROWS_AS(
+			rxman.handle_action("an-invalid-command", params),
+			confighandlerexception);
 	}
 }
 
 TEST_CASE("RegexManager doesn't throw on valid `highlight' definition",
-          "[regexmanager]")
+	"[regexmanager]")
 {
 	regexmanager rxman;
 	std::vector<std::string> params;
@@ -53,8 +58,7 @@ TEST_CASE("RegexManager doesn't throw on valid `highlight' definition",
 	REQUIRE_NOTHROW(rxman.handle_action("highlight", params));
 }
 
-TEST_CASE("RegexManager highlights according to definition",
-          "[regexmanager]")
+TEST_CASE("RegexManager highlights according to definition", "[regexmanager]")
 {
 	regexmanager rxman;
 	std::string input;
@@ -71,7 +75,7 @@ TEST_CASE("RegexManager highlights according to definition",
 }
 
 TEST_CASE("RegexManager preserves text when there's nothing to highlight",
-          "[regexmanager]")
+	"[regexmanager]")
 {
 	regexmanager rxman;
 	std::string input = "xbarx";
@@ -87,16 +91,18 @@ TEST_CASE("RegexManager preserves text when there's nothing to highlight",
 	REQUIRE(input == "a<b>");
 }
 
-TEST_CASE("`highlight all` adds rules for all locations", "[regexmanager]") {
+TEST_CASE("`highlight all` adds rules for all locations", "[regexmanager]")
+{
 	regexmanager rxman;
 	std::vector<std::string> params = {"all", "foo", "red"};
 	REQUIRE_NOTHROW(rxman.handle_action("highlight", params));
 	std::string input = "xxfooyy";
 
 	for (auto location : {"article", "articlelist", "feedlist"}) {
-		SECTION(location) {
-		rxman.quote_and_highlight(input, location);
-		REQUIRE(input == "xx<0>foo</>yy");
+		SECTION(location)
+		{
+			rxman.quote_and_highlight(input, location);
+			REQUIRE(input == "xx<0>foo</>yy");
 		}
 	}
 }
